@@ -74,7 +74,7 @@ async def get_kernels():
 @router.delete("/api/sessions/{session_id}", status_code=204)
 async def delete_session(
     session_id: str,
-    user: User = Depends(current_user()),
+    user: User = Depends(current_user),
 ):
     kernel_id = sessions[session_id]["kernel"]["id"]
     kernel_server = kernels[kernel_id]["server"]
@@ -87,7 +87,7 @@ async def delete_session(
 @router.patch("/api/sessions/{session_id}")
 async def rename_session(
     request: Request,
-    user: User = Depends(current_user()),
+    user: User = Depends(current_user),
 ):
     rename_session = await request.json()
     session_id = rename_session.pop("id")
@@ -115,7 +115,7 @@ async def get_sessions():
 )
 async def create_session(
     request: Request,
-    user: User = Depends(current_user()),
+    user: User = Depends(current_user),
 ):
     create_session = await request.json()
     kernel_name = create_session["kernel"]["name"]
@@ -149,7 +149,7 @@ async def create_session(
 @router.post("/api/kernels/{kernel_id}/restart")
 async def restart_kernel(
     kernel_id,
-    user: User = Depends(current_user()),
+    user: User = Depends(current_user),
 ):
     if kernel_id in kernels:
         kernel = kernels[kernel_id]
@@ -167,7 +167,7 @@ async def restart_kernel(
 @router.get("/api/kernels/{kernel_id}")
 async def get_kernel(
     kernel_id,
-    user: User = Depends(current_user()),
+    user: User = Depends(current_user),
 ):
     if kernel_id in kernels:
         kernel = kernels[kernel_id]
